/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-01-04 10:23+0100\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.0.5\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""
 ,""

]
, "Application, Applications"
: [
  "Anwendung"
 ,"Anwendungen"

]
, "User, Users"
: [
  "Benutzer"
 ,"Benutzer"

]
, "Groups"
: "Gruppen"

, "Roles"
: "Rollen"

, "Applications"
: "Anwendungen"

, "Containers"
: "Container"

, "Shared Tags"
: "Gemeinsame Tags"

, "Customfields"
: "Zusatzfelder"

, "Computers"
: "Computer"

, "Access Log, Access Logs"
: [
  "Zugriffslog"
 ,"Zugriffslogs"

]
, "Log"
: ""

, "Server Information"
: "Server Informationen"

, "ActiveSync Devices"
: "ActiveSync Geräte"

, "E-mail Accounts"
: "E-Mail Konten"

, "Import Export Definitions"
: ""

, "Admin"
: "Admin"

, "Refresh"
: "Aktualisieren"

, "Disabled"
: "Deaktiviert"

, "Feature is disabled by configuration."
: "Funktion ist durch die Konfiguration deaktiviert."

, "Default Addressbook for new contacts and groups"
: "Standard-Adressbuch für neue Kontakte und Gruppen"

, "Computer Name"
: "Computername"

, "Config, Configs"
: [
  "Konfiguration"
 ,"Konfigurationen"

]
, "Description"
: "Beschreibung"

, "Name"
: "Name"

, "Label"
: "Bezeichner"

, "Value"
: "Wert"

, "Default ({0})"
: "Standard ({0})"

, "Yes"
: "Ja"

, "No"
: "Nein"

, "Group Name"
: "Gruppenname"

, "Visibility"
: "Sichtbarkeit"

, "Display in addressbook"
: "Zeige im Adressbuch"

, "Hide from addressbook"
: "Nicht im Adressbuch anzeigen"

, "Saved in Addressbook"
: "Gespeichert im Adressbuch"

, "E-mail"
: "E-Mail"

, "Only system accounts can be added to Addressbook group"
: "Nur Systembenutzer in der zugehörigen Addressbuch-Gruppe erlauben"

, "Group Members"
: "Gruppenmitglieder"

, "Domain is not allowed. Check your SMTP domain configuration."
: "Domäne ist nicht erlaubt. Bitte prüfen Sie Ihre SMTP-Domänen-Konfiguration."

, "Confirm"
: "Bestätigen"

, "Do you really want to delete the selected tags?"
: "Möchten Sie den/die markierten Tag/s wirklich löschen?"

, "Deleting tag(s)..."
: "Tag(s) löschen..."

, "Add Tag"
: "Tag hinzufügen"

, "Edit Tag"
: "Tag bearbeiten"

, "Delete Tag"
: "Tags löschen"

, "Search:"
: "Suche:"

, "Displaying tags {0} - {1} of {2}"
: "Zeige Tag {0} - {1} von {2}"

, "No tags to display"
: "Keine Tags anzuzeigen"

, "ID"
: "ID"

, "Color"
: "Farbe"

, "Usage:&#160;"
: "Verwendung:&#160;"

, "Do you really want to delete the selected roles?"
: "Möchten Sie die ausgewählten Rollen wirklich löschen?"

, "Deleting role(s)..."
: "Lösche Rolle(n)..."

, "Failed"
: "Fehlgeschlagen"

, "Some error occurred while trying to delete the role."
: "Beim Löschen der Rolle trat ein Fehler auf."

, "Add Role"
: "Rolle hinzufügen"

, "Edit Role"
: "Rolle bearbeiten"

, "Delete Role"
: "Rolle löschen"

, "Displaying roles {0} - {1} of {2}"
: "Zeige Rollen {0} - {1} von {2}"

, "No roles to display"
: "Keine Rollen zum Anziegen"

, "Container Name"
: "Containername"

, "Type"
: "Typ"

, "Container Order"
: "Container Reihenfolge"

, "Container, Containers"
: [
  "Container"
 ,"Container"

]
, "Model"
: "Modell"

, "personal"
: "persönlich"

, "shared"
: "gemeinsam"

, "Order"
: "Sortierung"

, "Container Hierarchy/Name"
: "Kalender Hierarchie/Name"

, "Note for Owner"
: "Notiz für den Besitzer"

, "Info"
: "Info"

, "Please create Resources in Addressbook or CoreData."
: "Bitte Ressourcen im Addressbook oder Stammdaten erstellen."

, "Do you really want to delete the selected groups?"
: "Die ausgewählten Gruppen wirklich löschen?"

, "Deleting group(s)..."
: "Lösche Gruppe(n)..."

, "Some error occurred while trying to delete the group."
: "Beim Löschen der Gruppe trat ein Fehler auf."

, "Add Group"
: "Gruppe hinzufügen"

, "Edit Group"
: "Gruppe bearbeiten"

, "Delete Group"
: "Gruppe löschen"

, "Displaying groups {0} - {1} of {2}"
: "Zeige Gruppen {0} - {1} von {2}"

, "No groups to display"
: "Keine Gruppen anzuzeigen"

, "Account only"
: "Nur Systembenutzer"

, "Creation Time"
: "Erstellungszeit"

, "Created By"
: "Erstellt von"

, "Last Modified Time"
: "Änderungszeit"

, "Last Modified By"
: "Letzte Änderung von"

, "IP Address"
: "IP-Adresse"

, "Login Time"
: "Einlogzeit"

, "Logout Time"
: "Auslogzeit"

, "Client Type"
: "Client-Typ"

, "Session ID"
: "Session-ID"

, "Login Name"
: "Benutzername"

, "Result"
: "Ergebnis"

, "User Agent"
: ""

, "user blocked"
: "Benutzer gesperrt"

, "password expired"
: "Passwort abgelaufen"

, "user disabled"
: "Benutzer deaktiviert"

, "invalid password"
: "ungültiges Passwort"

, "ambiguous username"
: "Benutzername mehrdeutig"

, "user not found"
: "Benutzer nicht gefunden"

, "failure"
: "Gescheitert"

, "success"
: "Erfolg"

, "Customfield, Customfields"
: [
  "Zusatzfeld"
 ,"Zusatzfelder"

]
, "This custom field is still in use!"
: "Ein Zusatzfeld ist noch in Benutzung!"

, "Are you sure you want to delete them?"
: "Sind Sie sicher, dass Sie es löschen möchten?"

, "Errors"
: "Fehler"

, "Please configure store for this field type"
: "Bitte konfigurieren Sie einen Datenspeicher für diesen Feldtyp"

, "Record Class"
: "Datensatz-Klasse"

, "Given record class not found"
: "Datensatz-Klasse nicht gefunden"

, "Cancel"
: "Abbruch"

, "OK"
: "OK"

, "Configure store"
: "Datenspeicher konfigurieren"

, "Custom field definition"
: "Zusatzfeld-Definition"

, "Text"
: "Text"

, "Textarea"
: "Textarea"

, "Number"
: "Zahl"

, "Date"
: "Datum"

, "DateTime"
: "Datum mit Uhrzeit"

, "Time"
: "Uhrzeit"

, "Boolean"
: "Logischer Term"

, "Search Combo"
: "Suchfeld"

, "Key Field"
: "Schlüsselfeld"

, "Record"
: "Datensatz"

, "Record List"
: "Datensatz Liste"

, "Length"
: "Länge"

, "Required"
: "Erforderlich"

, "Custom field additional properties"
: "Zusätzliche Eigenschaft des Zusatzfeldes"

, "Tab Panel"
: "Karteireiter"

, "Group, Groups"
: [
  "Gruppe"
 ,"Gruppen"

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: "Es gibt bereits ein Zusatzfeld mit diesem Namen. Bitte wählen Sie einen anderen Namen."

, "Enable Account"
: "Benutzer aktivieren"

, "Disable Account"
: "Benutzer deaktivieren"

, "Reset Password"
: "Passwort zurücksetzen"

, "Status"
: "Status"

, "Display name"
: "Bildschirmname"

, "Login name"
: "Anmeldename"

, "Last name"
: "Nachname"

, "First name"
: "Vorname"

, "E-mail usage"
: "E-Mail-Nutzung"

, "Filesystem usage"
: "Dateisystem Nutzung"

, "OpenID"
: "OpenID"

, "Last login at"
: "Zuletzt eingeloggt um"

, "Last login from"
: "Letzter Login von"

, "Password Must Change"
: "Passwort muss geändert werden"

, "Password changed"
: "Passwort geändert"

, "Expires"
: "Verfällt"

, "Set new password"
: "Passwort zurücksetzen"

, "Please enter the new password:"
: "Bitte geben Sie das neue Passwort ein:"

, "Users"
: "Benutzer"

, "Samba User, Samba Users"
: [
  "Samba-Benutzer"
 ,"Samba-Benutzer"

]
, "Email User, Email Users"
: [
  "E-Mail-Benutzer"
 ,"E-Mail-Benutzer"

]
, "Special characters are not allowed in login name."
: "Der Benutzername darf keine Sonderzeichen enthalten."

, "Passwords do not match!"
: "Passwörter sind ungleich!"

, "Passwords match!"
: "Passwörter stimmen überein!"

, "Primary group"
: "Stammgruppe"

, "Unix"
: "Unix"

, "Home Directory"
: "Home-Verzeichnis"

, "Login Shell"
: "Login-Shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Home-Festplatte"

, "never logged in"
: "war noch nie eingeloggt"

, "Home Path"
: "Home-Pfad"

, "never logged off"
: "hat sich niemals ausgeloggt"

, "Profile Path"
: "Profilverzeichnis"

, "Password Last Set"
: "Passwort zuletzt gesetzt"

, "never"
: "nie"

, "Logon Script"
: "Login Skript"

, "Password Can Change"
: "Passwort kann geändert werden"

, "not set"
: "nicht gesetzt"

, "Kick Off Time"
: "Abmeldezeit"

, "Filesystem Quota"
: "Dateisystem Kontingent"

, "Quota"
: "Kontingent"

, "no quota set"
: "kein Kontingent gesetzt"

, "Current Filesystem usage"
: "Derzeitige Dateisystem Nutzung"

, "IMAP Quota"
: "IMAP Kontingent"

, "Current Mailbox size"
: "Aktuelle Mailboxgröße"

, "Sieve Quota"
: "SIEVE Kontingent"

, "Current Sieve size"
: "Aktuelle Sieve-Skriptgröße"

, "Information"
: "Informationen"

, "Last Login"
: "Zuletzt eingeloggt um"

, "Forward Only"
: "Nur Weiterleiten"

, "E-mail Alias"
: "E-Mail Alias"

, "Add an alias address..."
: "E-Mail-Adresse hinzufügen..."

, "This alias can be used for sending e-mails."
: "Dieser Alias kann zum Versenden von E-Mails verwendet werden."

, "Domain not allowed"
: "Domäne nicht erlaubt"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: "Die Domäne {0} des neuen Alias {1} ist nicht als primäre oder sekundäre Domäne im Setup eingetragen. Bitte fügen Sie diese Domain als sekundäre Domain im SMTP setup hinzu oder benutzen Sie eine Domäne welche bereits konfiguriert ist."

, "Forwarding to self"
: "Weiterleitung zu sich selbst"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: "Sie dürfen keine E-Mail-Adresse zur Weiterleitung festlegen, die mit der primären E-Mail-Adresse des Benutzers oder einem seiner Aliase identisch ist."

, "E-mail Forward"
: "E-Mail weiterleiten"

, "Add a forwarding address..."
: "Eine Weiterleitungs-Adresse hinzufügen..."

, "Password confirmation"
: "Passwortbestätigung"

, "Repeat password"
: "Passwort wiederholen"

, "Ok"
: "Ok"

, "Account"
: "Benutzerkonto"

, "Password"
: "Passwort"

, "Multi Factor Authentication Config"
: "Multi-Faktor-Authentifizierung"

, "enabled"
: "aktiviert"

, "disabled"
: "deaktiviert"

, "expired"
: "abgelaufen"

, "blocked"
: "gesperrt"

, "Invalid Status"
: "Ungültiger Status"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Der \"gesperrt\"-Status erscheint nur, wenn der Benutzer sich zu oft mit falschem Passwort anmelden wollte. Es ist nicht möglich diesen Status zu setzten."

, "don't know"
: "unbekannt"

, "Password set"
: "Passwort gesetzt"

, "User groups"
: "Gruppen"

, "User roles"
: "Rollen"

, "Fileserver"
: "Fileserver"

, "Filesystem"
: "Dateisystem"

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "Computer"
 ,"Computer"

]
, "Please wait"
: "Bitte warten"

, "Updating Memberships"
: "Mitgliedschaft erneuern"

, "Could not save role."
: "Konnte die Rolle nicht speichern."

, "Please fix the errors noted."
: "Bitte beheben Sie die angezeigten Fehler."

, "Deleting role..."
: "Rolle löschen ..."

, "Rights"
: "Rechte"

, "Members"
: "Mitglieder"

, "Role Name"
: "Rollennname"

, "Transferring {0}..."
: "Übertrage {0} ..."

, "Role"
: "Rolle"

, "Add New Role"
: "Neue Rolle hinzufügen"

, "Edit Role \"{0}\""
: "Rolle \"{0}\" bearbeiten"

, "Configs"
: "Konfigurationen"

, "Size"
: "Größe"

, "Revision Size"
: "Revisions-Größe"

, "Total size of all available revisions"
: "Gesamtgröße aller verfügbaren Revisionen"

, "Quota Management"
: "Kontingents-Verwaltung"

, "Edit Quota"
: "Kontingent bearbeiten"

, "Edit {0} Quota"
: "{0} Kontingent bearbeiten"

, "Manage total Filesystem Quota"
: "Gesamte Dateimanager Quota verwalten"

, "Total quota"
: "Gesamte Quota"

, "Updating Tag"
: "Aktualisiere Tag"

, "Could not save tag ({0})"
: "Konnte Tag ({0}) nicht speichern"

, "Allowed Contexts"
: "Erlaubte Kontexte"

, "Context"
: "Kontexte"

, "Account Rights"
: "Benutzerrechte"

, "View"
: "Zeigen"

, "Use"
: "Verwenden"

, "Tag Name"
: "Tag Name"

, "Tag"
: "Tag"

, "Add New Tag"
: "Neuen Tag hinzufügen"

, "Edit Tag \"{0}\""
: "Tag \"{0}\" bearbeiten"

, "Enable Application"
: "Anwendung aktivieren"

, "Disable Application"
: "Anwendung deaktivieren"

, "Settings"
: "Einstellungen"

, "{0} Settings"
: "{0} Einstellungen"

, "Enabled"
: "Aktiviert"

, "Unknown status ({0})"
: "Unbekannter Status ({0})"

, "Displaying application {0} - {1} of {2}"
: "Zeige Anwendung {0} - {1} von {2}"

, "No applications to display"
: "Keine Anwendungen anzuzeigen"

, "Version"
: "Version"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: "Standard IMAP-Benutzer-Einstellungen"

, "Enabled Features"
: "Aktiviertes Features"

, "Enabled Features in Admin Application."
: "Aktiviertes Features in der Admin Anwendung."

, "Prevent special chars in login name"
: "Vermeiden Sie Sonderzeichen im Anmeldenamen"

, "Force retype of new password in user edit dialog"
: "Erzwinge die erneute Eingabe des neuen Passworts im Benutzer-Bearbeitungsdialog"

, "Your container has been changed"
: "Ihr persönlicher Container wurde geändert"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Ihr Container wurde von %1$s geändert %2$sNotiz: %3$s"

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: "Zugriffsprotokoll bearbeiten"

, "Delete access log entries."
: "Zugriffsprotokoll-Einträge löschen."

, "Manage accounts"
: "Benutzerkonten verwalten"

, "Add and edit users and groups, add group members, change user passwords."
: "Benutzer und Gruppen anlegen und bearbeiten, Benutzer zu Gruppen zuordnen, Passwörter zurücksetzen."

, "Manage e-mail accounts"
: "E-Mail Konten verwalten"

, "Add and edit shared and personal e-mail accounts."
: "Persönliche und gemeinsame E-Mail Konten ansehen."

, "Manage applications"
: "Anwendungen verwalten"

, "Enable and disable applications, edit application settings."
: "Anwendungen bearbeiten, aktivieren und deaktivieren."

, "Manage roles"
: "Rollen verwalten"

, "Add and edit roles, add new members to roles, add application rights to roles."
: "Rollen anlegen und bearbeiten, Benutzerkonten Rollen zuordnen, Rollen Anwendungs-Rechte zuweisen."

, "Manage shared tags"
: "Gemeinsame Tags verwalten"

, "Add, delete and edit shared tags."
: "Gemeinsame Tags anlegen, bearbeiten und löschen."

, "Manage computers"
: "Computer verwalten"

, "Add, delete and edit (samba) computers."
: "(Samba-) Computer hinzufügen, löschen und bearbeiten."

, "Manage containers"
: "Container verwalten"

, "Add, delete and edit containers and manage container grants."
: "Container anlegen, löschen und ändern, sowie die Container-Rechte setzen."

, "Manage customfields"
: "Zusatzfelder verwalten"

, "Add and edit customfields."
: "Zusatzfelder anlegen und editieren."

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: "Zugriffsprotokoll ansehen"

, "View access log list."
: "Zugriffsprotokoll-Liste ansehen."

, "View accounts"
: "Benutzerkonten ansehen"

, "View accounts list and details."
: "Benutzerkonten ansehen (Liste und Details)"

, "View e-mail accounts"
: "E-Mail Konten ansehen"

, "View shared and personal e-mail accounts."
: "Persönliche und gemeinsame E-Mail Konten ansehen."

, "View applications"
: "Anwendungen ansehen"

, "View applications list and details."
: "Anwendungen ansehen (Liste und Details)"

, "View roles"
: "Rollen ansehen"

, "View roles list and details."
: "Rollen ansehen (Liste und Details)"

, "View shared tags"
: "Gemeinsame Tags ansehen"

, "View shared tags list and details."
: "Gemeinsame Tags ansehen (Liste und Details)"

, "View computers"
: "Computer ansehen"

, "View computers list and details."
: "Computerliste und -details ansehen."

, "View containers"
: "Container ansehen"

, "View personal and shared containers."
: "Persönlichen und gemeinsame Container ansehen."

, "View customfields"
: "Zusatzfelder ansehen"

, "View customfields list."
: "Liste der Zusatzfelder ansehen."

, "View serverinfo"
: "Serverinformationen ansehen"

, "View serverinfo list."
: "Listen der Serverinformationen ansehen."

, "View quota usage"
: "Quota Nutzung ansehen"

, "View quota usage."
: "Quota Nutzung ansehen."

, "view ImportExportDefinitions"
: ""

, "Record data needs to be set!"
: "Datensatz muss gesetzt sein!"

, "Account E-Mail needs to be set!"
: "Konto E-Mail muss gesetzt sein!"

, "E-Mail account not found."
: "E-Mail-Konto nicht gefunden."

, "It is not allowed to manage total Quota."
: "Es ist nicht erlaubt, die Gesamte Quota zu verwalten."

, "Delete user will trigger the [V] events, do you still want to execute this action?"
: "Das Löschen des Benutzers wird die mit [V] markierten Aktionen auslösen, wollen Sie das Löschen durchführen?"

, "Delete personal containers"
: "Persönliche Ordner löschen"

, "Keep account as contact in the Addressbook"
: "Als Kontakt im Adressbuch behalten"

, "Keep accounts organizer events as external events in the Calendar"
: "Organisator-Termine der Benutzer:in als externe Termine im Kalender behalten"

, "Keep accounts Calendar event attendee as external attender"
: "Termine der Benutzer:in als externe Termine im Kalender behalten"

, "Delete file folders and files"
: "Dateiordner und Dateien löschen"

, "Delete Email accounts"
: "E-Mail-Konten löschen"
































































, "ImportExportDefinition"
: ""

, "Application"
: "Anwendung"

, "User"
: "Benutzer"

, "Access Log"
: "Zugriffslog"

, "Config"
: "Konfiguration"

, "Container"
: "Container"

, "Customfield"
: "Zusatzfeld"

, "Group"
: "Gruppe"

, "Samba User"
: "Samba-Benutzer"

, "Email User"
: "E-Mail-Benutzer"

, "Computer"
: "Computer"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
